#
# Check out the descrption at:
# https://home.et.utwente.nl/slootenvanf/2025/03/07/create-rgb-led-controller-app/
#
from machine import Pin, PWM

try:
    import bluetooth
except ImportError as e:
    import sys
    sys.exit("bluetooth module not present")

from ble_simple_peripheral import BLESimplePeripheral
from time import sleep

# Initialize PWM for each color channel of an RGB LED
red = PWM(Pin(26))
green = PWM(Pin(27))
blue = PWM(Pin(28))

# Set frequency
red.freq(1000)
green.freq(1000)
blue.freq(1000)

def set_color(r, g, b):
    red.duty_u16(r)
    green.duty_u16(g)
    blue.duty_u16(b)

def on_rx(data):
    received = data.decode().strip()
    print("Data received: ", received)  # Print the received data
    try:
        r, g, b = map(int, received.split(","))
        set_color(r * 256, g * 256, b * 256)
    except ValueError:
        print("on_rx: error")

# blink 3x red:
for i in range(3):
    set_color(65535, 0, 0)  # Red
    sleep(0.5)
    set_color(0, 0, 0)  # Off
    sleep(0.5)

# Create a Bluetooth Low Energy (BLE) object
ble = bluetooth.BLE()

# Create an instance of the BLESimplePeripheral class with the BLE object and assign a unique name to the device:
sp = BLESimplePeripheral(ble, "pico-fvs")

# register the callback funcion on_rx:
sp.on_write(on_rx)


while True:
    if sp.is_connected():  # Check if a BLE connection is established
        sp.on_write(on_rx)  # Set the callback function for data reception

